SolValue

Trait SolValue 

pub trait SolValue: SolTypeValue<Self::SolType> {
    type SolType: SolType;

Show 16 methods // Provided methods fn sol_name(&self) -> &'static str { ... } fn tokenize(&self) -> <Self::SolType as SolType>::Token<'_> { ... } fn detokenize(token: <Self::SolType as SolType>::Token<'_>) -> Self where Self: From<<Self::SolType as SolType>::RustType> { ... } fn abi_encoded_size(&self) -> usize { ... } fn eip712_data_word(&self) -> FixedBytes<32> { ... } fn abi_encode_packed_to(&self, out: &mut Vec<u8>) { ... } fn abi_encode_packed(&self) -> Vec<u8> { ... } fn abi_encode(&self) -> Vec<u8> { ... } fn abi_encode_sequence(&self) -> Vec<u8> where <Self::SolType as SolType>::Token<'a>: for<'a> TokenSeq<'a> { ... } fn abi_encode_params(&self) -> Vec<u8> where <Self::SolType as SolType>::Token<'a>: for<'a> TokenSeq<'a> { ... } fn abi_decode(data: &[u8]) -> Result<Self, Error> where Self: From<<Self::SolType as SolType>::RustType> { ... } fn abi_decode_validate(data: &[u8]) -> Result<Self, Error> where Self: From<<Self::SolType as SolType>::RustType> { ... } fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self, Error> where Self: From<<Self::SolType as SolType>::RustType>, <Self::SolType as SolType>::Token<'de>: TokenSeq<'de> { ... } fn abi_decode_params_validate<'de>(data: &'de [u8]) -> Result<Self, Error> where Self: From<<Self::SolType as SolType>::RustType>, <Self::SolType as SolType>::Token<'de>: TokenSeq<'de> { ... } fn abi_decode_sequence<'de>(data: &'de [u8]) -> Result<Self, Error> where Self: From<<Self::SolType as SolType>::RustType>, <Self::SolType as SolType>::Token<'de>: TokenSeq<'de> { ... } fn abi_decode_sequence_validate<'de>(data: &'de [u8]) -> Result<Self, Error> where Self: From<<Self::SolType as SolType>::RustType>, <Self::SolType as SolType>::Token<'de>: TokenSeq<'de> { ... }
}
Re-exported alloy ABI types for use with generated calls. A Solidity value.

This is a convenience trait that re-exports the logic in SolType with less generic implementations so that they can be used as methods with self receivers.

See SolType for more information.

Implementer’s Guide

It should not be necessary to implement this trait manually. Instead, use the sol! procedural macro to parse Solidity syntax into types that implement this trait.

Examples

use alloy_sol_types::SolValue;

let my_values = ("hello", 0xdeadbeef_u32, true, [0x42_u8; 24]);
let _ = my_values.abi_encode();
let _ = my_values.abi_encode_packed();
assert_eq!(my_values.sol_name(), "(string,uint32,bool,bytes24)");

Required Associated Types

type SolType: SolType

The Solidity type that this type corresponds to.

Provided Methods

fn sol_name(&self) -> &'static str

The name of the associated Solidity type.

See SolType::SOL_NAME for more information.

fn tokenize(&self) -> <Self::SolType as SolType>::Token<'_>

Tokenizes the given value into this type’s token.

See SolType::tokenize for more information.

fn detokenize(token: <Self::SolType as SolType>::Token<'_>) -> Self
where Self: From<<Self::SolType as SolType>::RustType>,

Detokenize a value from the given token.

See SolType::detokenize for more information.

fn abi_encoded_size(&self) -> usize

Calculate the ABI-encoded size of the data.

See SolType::abi_encoded_size for more information.

fn eip712_data_word(&self) -> FixedBytes<32>

Encode this data according to EIP-712 encodeData rules, and hash it if necessary.

See SolType::eip712_data_word for more information.

fn abi_encode_packed_to(&self, out: &mut Vec<u8>)

Non-standard Packed Mode ABI encoding.

See SolType::abi_encode_packed_to for more information.

fn abi_encode_packed(&self) -> Vec<u8>

Non-standard Packed Mode ABI encoding.

See SolType::abi_encode_packed for more information.

fn abi_encode(&self) -> Vec<u8>

ABI-encodes the value.

See SolType::abi_encode for more information.

fn abi_encode_sequence(&self) -> Vec<u8>
where <Self::SolType as SolType>::Token<'a>: for<'a> TokenSeq<'a>,

Encodes an ABI sequence.

See SolType::abi_encode_sequence for more information.

fn abi_encode_params(&self) -> Vec<u8>
where <Self::SolType as SolType>::Token<'a>: for<'a> TokenSeq<'a>,

Encodes an ABI sequence suitable for function parameters.

See SolType::abi_encode_params for more information.

fn abi_decode(data: &[u8]) -> Result<Self, Error>
where Self: From<<Self::SolType as SolType>::RustType>,

ABI-decode this type from the given data.

See SolType::abi_decode for more information.

fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
where Self: From<<Self::SolType as SolType>::RustType>,

ABI-decode this type from the given data, with validation.

See SolType::abi_decode_validate for more information.

fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self, Error>
where Self: From<<Self::SolType as SolType>::RustType>, <Self::SolType as SolType>::Token<'de>: TokenSeq<'de>,

ABI-decode this type from the given data.

See SolType::abi_decode_params for more information.

fn abi_decode_params_validate<'de>(data: &'de [u8]) -> Result<Self, Error>
where Self: From<<Self::SolType as SolType>::RustType>, <Self::SolType as SolType>::Token<'de>: TokenSeq<'de>,

ABI-decode this type from the given data, with validation.

See SolType::abi_decode_params_validate for more information.

fn abi_decode_sequence<'de>(data: &'de [u8]) -> Result<Self, Error>
where Self: From<<Self::SolType as SolType>::RustType>, <Self::SolType as SolType>::Token<'de>: TokenSeq<'de>,

ABI-decode this type from the given data.

See SolType::abi_decode_sequence for more information.

fn abi_decode_sequence_validate<'de>(data: &'de [u8]) -> Result<Self, Error>
where Self: From<<Self::SolType as SolType>::RustType>, <Self::SolType as SolType>::Token<'de>: TokenSeq<'de>,

ABI-decode this type from the given data, with validation.

See SolType::abi_decode_sequence_validate for more information.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl SolValue for ()

Source

impl SolValue for Address

Source

impl SolValue for Function

Source

impl SolValue for Signed<24, 1>

Source

type SolType = Int<24>

Source

impl SolValue for Signed<40, 1>

Source

type SolType = Int<40>

Source

impl SolValue for Signed<48, 1>

Source

type SolType = Int<48>

Source

impl SolValue for Signed<56, 1>

Source

type SolType = Int<56>

Source

impl SolValue for Signed<72, 2>

Source

type SolType = Int<72>

Source

impl SolValue for Signed<80, 2>

Source

type SolType = Int<80>

Source

impl SolValue for Signed<88, 2>

Source

type SolType = Int<88>

Source

impl SolValue for Signed<96, 2>

Source

type SolType = Int<96>

Source

impl SolValue for Signed<104, 2>

Source

type SolType = Int<104>

Source

impl SolValue for Signed<112, 2>

Source

type SolType = Int<112>

Source

impl SolValue for Signed<120, 2>

Source

type SolType = Int<120>

Source

impl SolValue for Signed<136, 3>

Source

type SolType = Int<136>

Source

impl SolValue for Signed<144, 3>

Source

type SolType = Int<144>

Source

impl SolValue for Signed<152, 3>

Source

type SolType = Int<152>

Source

impl SolValue for Signed<160, 3>

Source

type SolType = Int<160>

Source

impl SolValue for Signed<168, 3>

Source

type SolType = Int<168>

Source

impl SolValue for Signed<176, 3>

Source

type SolType = Int<176>

Source

impl SolValue for Signed<184, 3>

Source

type SolType = Int<184>

Source

impl SolValue for Signed<192, 3>

Source

type SolType = Int<192>

Source

impl SolValue for Signed<200, 4>

Source

type SolType = Int<200>

Source

impl SolValue for Signed<208, 4>

Source

type SolType = Int<208>

Source

impl SolValue for Signed<216, 4>

Source

type SolType = Int<216>

Source

impl SolValue for Signed<224, 4>

Source

type SolType = Int<224>

Source

impl SolValue for Signed<232, 4>

Source

type SolType = Int<232>

Source

impl SolValue for Signed<240, 4>

Source

type SolType = Int<240>

Source

impl SolValue for Signed<248, 4>

Source

type SolType = Int<248>

Source

impl SolValue for Signed<256, 4>

Source

type SolType = Int<256>

Source

impl SolValue for String

Source

impl SolValue for Uint<24, 1>

Source

impl SolValue for Uint<40, 1>

Source

impl SolValue for Uint<48, 1>

Source

impl SolValue for Uint<56, 1>

Source

impl SolValue for Uint<72, 2>

Source

impl SolValue for Uint<80, 2>

Source

impl SolValue for Uint<88, 2>

Source

impl SolValue for Uint<96, 2>

Source

impl SolValue for Uint<104, 2>

Source

type SolType = Uint<104>

Source

impl SolValue for Uint<112, 2>

Source

type SolType = Uint<112>

Source

impl SolValue for Uint<120, 2>

Source

type SolType = Uint<120>

Source

impl SolValue for Uint<136, 3>

Source

type SolType = Uint<136>

Source

impl SolValue for Uint<144, 3>

Source

type SolType = Uint<144>

Source

impl SolValue for Uint<152, 3>

Source

type SolType = Uint<152>

Source

impl SolValue for Uint<160, 3>

Source

type SolType = Uint<160>

Source

impl SolValue for Uint<168, 3>

Source

type SolType = Uint<168>

Source

impl SolValue for Uint<176, 3>

Source

type SolType = Uint<176>

Source

impl SolValue for Uint<184, 3>

Source

type SolType = Uint<184>

Source

impl SolValue for Uint<192, 3>

Source

type SolType = Uint<192>

Source

impl SolValue for Uint<200, 4>

Source

type SolType = Uint<200>

Source

impl SolValue for Uint<208, 4>

Source

type SolType = Uint<208>

Source

impl SolValue for Uint<216, 4>

Source

type SolType = Uint<216>

Source

impl SolValue for Uint<224, 4>

Source

type SolType = Uint<224>

Source

impl SolValue for Uint<232, 4>

Source

type SolType = Uint<232>

Source

impl SolValue for Uint<240, 4>

Source

type SolType = Uint<240>

Source

impl SolValue for Uint<248, 4>

Source

type SolType = Uint<248>

Source

impl SolValue for Uint<256, 4>

Source

type SolType = Uint<256>

Source

impl SolValue for Vec<u8>

Source

impl SolValue for [u8]

Source

impl SolValue for bool

Source

impl SolValue for i8

Source

impl SolValue for i16

Source

type SolType = Int<16>

Source

impl SolValue for i32

Source

type SolType = Int<32>

Source

impl SolValue for i64

Source

type SolType = Int<64>

Source

impl SolValue for i128

Source

type SolType = Int<128>

Source

impl SolValue for str

Source

impl SolValue for u16

Source

impl SolValue for u32

Source

impl SolValue for u64

Source

impl SolValue for u128

Source

type SolType = Uint<128>

Source

impl<'a, T> SolValue for &'a T
where T: SolValue + ?Sized, &'a T: SolTypeValue<<T as SolValue>::SolType>,

Source

impl<'a, T> SolValue for &'a mut T
where T: SolValue + ?Sized, &'a mut T: SolTypeValue<<T as SolValue>::SolType>,

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22, T23, T24> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22, T23, T24)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue, T13: SolValue, T14: SolValue, T15: SolValue, T16: SolValue, T17: SolValue, T18: SolValue, T19: SolValue, T20: SolValue, T21: SolValue, T22: SolValue, T23: SolValue, T24: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType, <T13 as SolValue>::SolType, <T14 as SolValue>::SolType, <T15 as SolValue>::SolType, <T16 as SolValue>::SolType, <T17 as SolValue>::SolType, <T18 as SolValue>::SolType, <T19 as SolValue>::SolType, <T20 as SolValue>::SolType, <T21 as SolValue>::SolType, <T22 as SolValue>::SolType, <T23 as SolValue>::SolType, <T24 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22, T23> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22, T23)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue, T13: SolValue, T14: SolValue, T15: SolValue, T16: SolValue, T17: SolValue, T18: SolValue, T19: SolValue, T20: SolValue, T21: SolValue, T22: SolValue, T23: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType, <T13 as SolValue>::SolType, <T14 as SolValue>::SolType, <T15 as SolValue>::SolType, <T16 as SolValue>::SolType, <T17 as SolValue>::SolType, <T18 as SolValue>::SolType, <T19 as SolValue>::SolType, <T20 as SolValue>::SolType, <T21 as SolValue>::SolType, <T22 as SolValue>::SolType, <T23 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue, T13: SolValue, T14: SolValue, T15: SolValue, T16: SolValue, T17: SolValue, T18: SolValue, T19: SolValue, T20: SolValue, T21: SolValue, T22: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType, <T13 as SolValue>::SolType, <T14 as SolValue>::SolType, <T15 as SolValue>::SolType, <T16 as SolValue>::SolType, <T17 as SolValue>::SolType, <T18 as SolValue>::SolType, <T19 as SolValue>::SolType, <T20 as SolValue>::SolType, <T21 as SolValue>::SolType, <T22 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue, T13: SolValue, T14: SolValue, T15: SolValue, T16: SolValue, T17: SolValue, T18: SolValue, T19: SolValue, T20: SolValue, T21: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType, <T13 as SolValue>::SolType, <T14 as SolValue>::SolType, <T15 as SolValue>::SolType, <T16 as SolValue>::SolType, <T17 as SolValue>::SolType, <T18 as SolValue>::SolType, <T19 as SolValue>::SolType, <T20 as SolValue>::SolType, <T21 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue, T13: SolValue, T14: SolValue, T15: SolValue, T16: SolValue, T17: SolValue, T18: SolValue, T19: SolValue, T20: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType, <T13 as SolValue>::SolType, <T14 as SolValue>::SolType, <T15 as SolValue>::SolType, <T16 as SolValue>::SolType, <T17 as SolValue>::SolType, <T18 as SolValue>::SolType, <T19 as SolValue>::SolType, <T20 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue, T13: SolValue, T14: SolValue, T15: SolValue, T16: SolValue, T17: SolValue, T18: SolValue, T19: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType, <T13 as SolValue>::SolType, <T14 as SolValue>::SolType, <T15 as SolValue>::SolType, <T16 as SolValue>::SolType, <T17 as SolValue>::SolType, <T18 as SolValue>::SolType, <T19 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue, T13: SolValue, T14: SolValue, T15: SolValue, T16: SolValue, T17: SolValue, T18: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType, <T13 as SolValue>::SolType, <T14 as SolValue>::SolType, <T15 as SolValue>::SolType, <T16 as SolValue>::SolType, <T17 as SolValue>::SolType, <T18 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue, T13: SolValue, T14: SolValue, T15: SolValue, T16: SolValue, T17: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType, <T13 as SolValue>::SolType, <T14 as SolValue>::SolType, <T15 as SolValue>::SolType, <T16 as SolValue>::SolType, <T17 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue, T13: SolValue, T14: SolValue, T15: SolValue, T16: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType, <T13 as SolValue>::SolType, <T14 as SolValue>::SolType, <T15 as SolValue>::SolType, <T16 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue, T13: SolValue, T14: SolValue, T15: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType, <T13 as SolValue>::SolType, <T14 as SolValue>::SolType, <T15 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue, T13: SolValue, T14: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType, <T13 as SolValue>::SolType, <T14 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue, T13: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType, <T13 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue, T12: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType, <T12 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue, T11: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType, <T11 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue, T10: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType, <T10 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8, T9)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue, T9: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType, <T9 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8> SolValue for (T1, T2, T3, T4, T5, T6, T7, T8)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue, T8: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType, <T8 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6, T7> SolValue for (T1, T2, T3, T4, T5, T6, T7)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue, T7: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType, <T7 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5, T6> SolValue for (T1, T2, T3, T4, T5, T6)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue, T6: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType, <T6 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4, T5> SolValue for (T1, T2, T3, T4, T5)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue, T5: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType, <T5 as SolValue>::SolType)

Source

impl<T1, T2, T3, T4> SolValue for (T1, T2, T3, T4)
where T1: SolValue, T2: SolValue, T3: SolValue, T4: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType, <T4 as SolValue>::SolType)

Source

impl<T1, T2, T3> SolValue for (T1, T2, T3)
where T1: SolValue, T2: SolValue, T3: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType, <T3 as SolValue>::SolType)

Source

impl<T1, T2> SolValue for (T1, T2)
where T1: SolValue, T2: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType, <T2 as SolValue>::SolType)

Source

impl<T1> SolValue for (T1,)
where T1: SolValue,

Source

type SolType = (<T1 as SolValue>::SolType,)

Source

impl<T, const N: usize> SolValue for [T; N]
where T: SolValue,

Source

impl<T> SolValue for Vec<T>
where T: SolValue,

Source

impl<T> SolValue for [T]
where T: SolValue,

Source

impl<const N: usize> SolValue for FixedBytes<N>

Source

impl<const N: usize> SolValue for [u8; N]

Implementors